<?php

namespace Drupal\oidc\EventSubscriber;

use Drupal\Core\Routing\RouteBuildEvent;
use Drupal\Core\Routing\RoutingEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber for the route events.
 */
class RouteEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[RoutingEvents::ALTER][] = 'onAlter';

    return $events;
  }

  /**
   * Alters the built routes.
   *
   * @param \Drupal\Core\Routing\RouteBuildEvent $event
   *   The route build event.
   */
  public function onAlter(RouteBuildEvent $event) {
    $collection = $event->getRouteCollection();

    // Make the user register and pass routes inaccessible.
    $collection->get('user.register')
      ->addRequirements([
        '_access' => 'FALSE',
      ]);

    $collection->get('user.pass')
      ->addRequirements([
        '_access' => 'FALSE',
      ]);

    // Change the title callback for some user routes.
    $collection->get('entity.user.canonical')
      ->setDefault('_title_callback', 'oidc_user_title');

    $collection->get('entity.user.edit_form')
      ->setDefault('_title_callback', 'oidc_user_title');
  }

}
